#
# rhel.py
#
# Copyright (C) 2010  Red Hat, Inc.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from installclass import BaseInstallClass
from constants import *
from product import *
from flags import flags
import os
import types

import installmethod
import yuminstall

class InstallClass(BaseInstallClass):
    # name has underscore used for mnemonics, strip if you dont need it
    id = "rels"
    name = N_("ROSA Enterprise Linux Server")
    _description = N_("The default installation of %s includes LXDE desktop, "
                     "ROSA Server Setup configuration utility and common server "
                     "components. You can optionally select a different set of "
                     "software now.")
    _descriptionFields = (productName,)
    sortPriority = 10010

    bootloaderTimeoutDefault = 5
    bootloaderExtraArgs = ["crashkernel=auto vga=788"]

    _tasks = [
             (N_("Standard ROSA Server (recommended)"),
              ["base", "console-internet", "core", "debugging",
               "directory-client", "hardware-monitoring", "java-platform",
               "large-systems", "network-file-system-client",
               "performance", "perl-runtime", "server-platform",
               "x11", "lxde-desktop", "fonts",
               "rosa-server-setup"],
              N_("Standard installation of ROSA Enterprise Linux Server "
                 "includes LXDE desktop, ROSA Server Setup service and basic "
                 "server components. If necessary, you can change the set of "
                 "installed components.")),
             (N_("Database Server"),
              ["base", "console-internet", "core", "debugging",
               "directory-client", "hardware-monitoring", "java-platform",
               "large-systems", "network-file-system-client",
               "performance", "perl-runtime", "server-platform",
               "mysql-client", "mysql", "postgresql-client", "postgresql",
               "system-admin-tools"],
              N_("Contains the base system and the client and server "
                 "components of MySQL and PostgreSQL. Does not contain "
                 "graphics. If necessary, you can change the set of "
                 "installed components.")),
             (N_("Web Server"),
              ["base", "console-internet", "core", "debugging",
               "directory-client", "java-platform",
               "network-file-system-client",
               "performance", "perl-runtime", "server-platform",
               "web-server", "web-servlet", "php", "turbogears",
               "mysql-client", "postgresql-client"],
              N_("Contains the base system and the components of the "
                 "web-server Apache, PHP language support and Java servlet "
                 "support. Does not contain graphics. If necessary, you can "
                 "change the set of installed components.")),
             (N_("Virtual Host"),
              ["base", "console-internet", "core", "debugging",
               "directory-client", "hardware-monitoring", "java-platform",
               "large-systems", "network-file-system-client",
               "performance", "perl-runtime", "server-platform",
               "virtualization", "virtualization-client",
               "virtualization-platform"],
              N_("Contains the base system, virtualization platform and tools "
                 "for managing virtual machines. Does not contain graphics. "
                 "If necessary, you can change the set of installed "
                 "components.")),
             (N_("Software Development Workstation"),
              ["base", "core", "debugging",
               "directory-client", "java-platform", "network-file-system-client",
               "performance", "perl-runtime", "server-platform",
               "fonts", "print-client",
               "basic-desktop", "desktop-debugging", "desktop-platform",
               "general-desktop", "graphical-admin-tools", "input-methods",
               "legacy-x", "x11", "internet-browser", "graphics", "emacs", "tex",
               "remote-desktop-clients", "virtualization", "virtualization-client",
               "virtualization-platform",
               "desktop-platform-devel", "development", "eclipse",
               "server-platform-devel", "technical-writing",
               "additional-devel"],
              N_("Contains the base system, graphics, GNOME desktop, Eclipse "
                 "IDE and the essential development tools, including the "
                 "development packages. If necessary, you can change the "
                 "set of installed components.")),
             (N_("Minimal"),
              ["core"],
              N_("Contains the base system. Does not contain graphics. If "
                 "necessary, you can change the set of installed components."))]

    def getPackagePaths(self, uri):
        if not type(uri) == types.ListType:
            uri = [uri,]

        return {productName: uri}

    def setInstallData(self, anaconda):
        BaseInstallClass.setInstallData(self, anaconda)
        BaseInstallClass.setDefaultPartitioning(self,
                                                anaconda.id.storage,
                                                anaconda.platform)

    def setSteps(self, anaconda):
        BaseInstallClass.setSteps(self, anaconda)
        anaconda.dispatch.skipStep("partition")

    def getBackend(self):
        if flags.livecdInstall:
            import livecd
            return livecd.LiveCDCopyBackend
        else:
            return yuminstall.YumBackend

    def productMatches(self, oldprod):
        if oldprod is None:
            return False

        if oldprod.startswith(productName):
            return True

        productUpgrades = {
#            "Red Hat Enterprise Linux AS": ("Red Hat Linux Advanced Server", ),
        }

        if productUpgrades.has_key(productName):
            acceptable = productUpgrades[productName]
        else:
            acceptable = ()

        for p in acceptable:
            if oldprod.startswith(p):
                return True

        return False

    def versionMatches(self, oldver):
        oldMajor = oldver.split(".")[0]
        newMajor = productVersion.split(".")[0]

        return oldMajor == newMajor

    def __init__(self):
        BaseInstallClass.__init__(self)
